@@ -6,9 +6,9 @@ import qhub.schema
 @pytest.mark.parametrize(
     "config_filename",
     [
-        "tests/assets/config_aws.yaml",
-        "tests/assets/config_gcp.yaml",
-        "tests/assets/config_do.yaml",
+        "qhub/template/configs/config_aws.yaml",
+        "qhub/template/configs/config_gcp.yaml",
+        "qhub/template/configs/config_do.yaml",
     ],
 )
 def test_validation(config_filename):
